from __future__ import unicode_literals

from django.conf import settings
from django.apps import AppConfig, apps
from django.contrib import admin

from .admin import AdminViewPermissionAdminSite
from .utils import django_version
from .enums import DjangoVersion

class AdminViewPermissionConfig(AppConfig):
    name = 'admin_view_permission'

    def ready(self):
        settings_models = getattr(settings, 'ADMIN_VIEW_PERMISSION_MODELS',
                                  None)

        if not isinstance(admin.site, AdminViewPermissionAdminSite):
            admin.site = AdminViewPermissionAdminSite('admin')
            admin.sites.site = admin.site

        # TODO: Maybe look at the registry not in all models
        for app in apps.get_app_configs():
            for model in app.get_models():
                if settings_models or (settings_models is not None and len(
                        settings_models) == 0):

                    if django_version() == DjangoVersion.DJANGO_18:
                        model_name = '%s.%s' %(model._meta.app_label,
                                               model._meta.object_name)
                    elif django_version() == DjangoVersion.DJANGO_19:
                        model_name = model._meta.label

                    if model_name in settings_models:
                        model._meta.permissions = (
                            ('view_%s' % model._meta.model_name,
                             'Can view %s' % model._meta.model_name),)
                else:
                    model._meta.permissions = (
                        ('view_%s' % model._meta.model_name,
                         'Can view %s' % model._meta.model_name),)



from __future__ import unicode_literals

import django

from .enums import DjangoVersion


def django_version():
    if django.get_version().startswith('1.9'):
        return DjangoVersion.DJANGO_19
    elif django.get_version().startswith('1.8'):
        return DjangoVersion.DJANGO_18



import os
from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-admin-view-permission',
    version='0.3',
    packages=['admin_view_permission'],
    include_package_data=True,
    license='BSD License',
    description='A simple Django app which adds view permissions.',
    long_description=README,
    keywords = ['django', 'admin'],
    url='http://django-admin-view-permission.readthedocs.org/',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.9',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    install_requires=[
        'Django>=1.8'
    ],
)